/*
  Extension       OEMtoggle
  Author          Carlo Hogeveen
  Website         eCarlo.nl/tse
  Compatibility   Windows GUI TSE v4.0 upwards
  Version         v1

  For Windows GUI TSE this extension allows you to toggle OEM on/off.

  This setting will work on fonts that default to ANSI but also support OEM

  The setting is remembered across TSE sessions and fonts.

  If OEM is ON for a font that does not support it, then Windows automatically
  selects a font that does, and the extension will warn you, showing the old
  and new font names.


  INSTALLATION

  Install the extension by copying this file to TSE's "mac" directory and
  compiling it there, for example by opening it there with TSE and by then
  applying the Macro Compile menu.

  Add the extension's name "OEMtoggle" to TSE's Macro AutoLoad List menu.


  CONFIGURATION

  Execute the extension as a macro to toggle the OEM setting on/off.

  Then press any key to activate the change.


  NOTES

  Some other tools and extensions are incompatible with OEM.

  The OEM character set is dependent on the Windows code page,
  which for GUI TSE is dependent on the Windows "locale" setting


  HISTORY

  v1   29 Feb 2024
    Initial version.

*/


// Global constatnts and semi-constants
string  CFG_SECTION_NAME [MAXSTRINGLEN] = ''
string  CFG_ITEM_NAME    [MAXSTRINGLEN] = 'OEM_status'


// Global variables
integer oem_status                   = 0
integer old_font_flags               = 0
string  old_font_name [MAXSTRINGLEN] = ''
integer old_font_size                = 0


proc check_oem()
  integer new_font_flags               = 0
  string  new_font_name [MAXSTRINGLEN] = ''
  integer new_font_size                = 0

  if QueryEditState() == 0
    GetFont(new_font_name, new_font_size, new_font_flags)

    if (new_font_flags & _FONT_OEM_) <> oem_status
      old_font_flags = new_font_flags
      old_font_name  = new_font_name
      old_font_size  = new_font_size

      if (new_font_flags & _FONT_OEM_) == _FONT_OEM_
        SetFont(new_font_name, new_font_size, new_font_flags & _FONT_BOLD_)
      else
        SetFont(new_font_name, new_font_size, new_font_flags | _FONT_OEM_)
      endif

      GetFont(old_font_name, old_font_size, old_font_flags)


      if new_font_name <> old_font_name
        Warn('OEM being ON changed "', new_font_name, '" to "',
             old_font_name, '".')
        GetKey() // Closing the Warn() from here adds an unwanted <Enter>.
      endif
    endif
  endif
end check_oem


proc toggle_oem()
  oem_status = iif(oem_status, 0, _FONT_OEM_)

  Message('OEM is set'; iif(oem_status, 'ON  ', 'OFF '))

  if not WriteProfileInt(CFG_SECTION_NAME, CFG_ITEM_NAME, oem_status)
    Warn('Failed to write configuration change to "tse.ini" file.')
  endif
end toggle_oem


proc WhenLoaded()
  GetFont(old_font_name, old_font_size, old_font_flags)
  CFG_SECTION_NAME = SplitPath(CurrMacroFilename(), _NAME_) + ':Config'
  oem_status       = GetProfileInt(CFG_SECTION_NAME, CFG_ITEM_NAME, 0)
  check_oem()
  Hook(_AFTER_GETKEY_, check_oem)
end WhenLoaded


proc Main()
  toggle_oem()
end Main


